#include <KafkaAvro_Provider.h>

using namespace inaf::oasbo::Providers;

KafkaAvroProviderBuilder::KafkaAvroProviderBuilder() {
	this->reset();
}
KafkaAvroProviderBuilder::KafkaAvroProviderBuilder(std::string ip, int port, std::string topic) {
	this->provider = new KafkaAvroProvider(ip, port, topic);
}
KafkaAvroProviderBuilder::~KafkaAvroProviderBuilder() {
	delete provider;
}

void KafkaAvroProviderBuilder::reset() {
	this->provider = new KafkaAvroProvider();
}

KafkaAvroProviderBuilder* KafkaAvroProviderBuilder::configFrom(Configurators::BaseConfigurator &conf) {
	conf.readConfigFromSource(config_target);
	std::map<std::string, std::string> params = conf.getConfig();

	std::string key = config_target+"_"+ip_key;
	if (params.count(key) > 0)
		provider->brokerIp = params[key];

	key = config_target+"_"+port_key;
	if (params.count(key) > 0)
		provider->brokerPort = std::stoi(params[key]);

	key = config_target+"_"+topic_key;
	if (params.count(key) > 0)
		provider->setDest(params[key]);
	return this;
}

KafkaAvroProviderBuilder* KafkaAvroProviderBuilder::setIp(std::string ip) {
	provider->brokerIp = ip;
	return this;
}

KafkaAvroProviderBuilder* KafkaAvroProviderBuilder::setPort(int port) {
	provider->brokerPort = port;
	return this;
}

KafkaAvroProviderBuilder* KafkaAvroProviderBuilder::setTopic(std::string topic) {
	provider->setDest(topic);
	return this;
}

KafkaAvroProvider* KafkaAvroProviderBuilder::getProvider() {
	KafkaAvroProvider *result = this->provider;
	this->reset();
	return result;
}
